@@ -14,6 +14,7 @@ from __future__ import (absolute_import, division, print_function,
 import os
 import sys
 import importlib
+import inspect
 
 
 def import_attribute(name):
@@ -34,9 +35,12 @@ def main():
     func_str = sys.argv[1]
     func = import_attribute(func_str)
 
-    #shfit command line arguments, so func can parse sys.argv properly.
-    sys.argv = sys.argv[1:]
-    func()
+    #Get func arguments values and shfit command line arguments,
+    #so func can parse sys.argv properly.
+    func_args = inspect.getargspec(func).args
+    func_args_values = sys.argv[2:2+len(func_args)]
+    sys.argv[1:] = sys.argv[2+len(func_args):]
+    return func(*func_args_values)
 
 
 if __name__ == '__main__':
